Date: 06 23, 2001 10:47:10 AM

# Using Highlighting

You can highlight regions of text in an analyzed file that match rules in a selected pass of the analyzer sequence using Highlight Mode. To use this highlighting feature, you must run the analyzer with Toggle Generate Log button selected.

To highlight regions in a text matching a pass:

1. Select the Toggle Generate Log button.

2. In the Text Tab, double click on a text file to open it in the Workspace.

3. Run the analyzer.

4. In the Ana Tab, select a pass.

5. Select the Toggle Highlight Mode button. The text matching the pass is highlighted in the text file. If a node has been created, the highlighting is blue. If a node has matched, the highlighting is green.

Note: You can also highlight text in a file that match selected rule concepts in the Gram Tab. To do this select the rule concept in the Gram Tab.